@@ -61,7 +61,7 @@ class Option(collections.namedtuple("Option", ["name", "type", "default", "min",
     pass
 
 
-class Score(collections.namedtuple("Score", ["cp", "mate", "lowerbound", "upperbound"])):
+class Score(collections.namedtuple("Score", ["cp", "mate"])):
     """A centipawns or mate score sent by an UCI engine."""
     pass
 
@@ -117,14 +117,28 @@ class OptionMap(collections.MutableMapping):
 class InfoHandler(object):
     """
     Chess engines may send information about their calculations with the
-    *info* command. You can register info handlers to be asynchronously
-    notified whenever the engine sends more information.
+    *info* command. Info handlers can be used to aggregate or react to this
+    information.
 
     >>> # Register a standard info handler.
     >>> info_handler = chess.uci.InfoHandler()
     >>> engine.info_handlers.append(info_handler)
 
-    You would usually subclass the *InfoHandler* class.
+    >>> # Start a search.
+    >>> engine.position(board)
+    >>> engine.go(movetime=1000)
+    BestMove(bestmove=Move.from_uci('e2e4'), ponder=Move.from_uci('e7e6'))
+    >>>
+    >>> # Retrieve the score of the mainline (PV 1) after search is completed.
+    >>> # Note that the score is relative to the side to move.
+    >>> info_handler.info["score"][1]
+    Score(cp=34, mate=None, lowerbound=False, upperbound=False)
+
+    See :attr:`~chess.uci.InfoHandler.info` for a way to access this dictionary
+    in a thread-safe way during search.
+
+    If you want to be notified whenever new information is available
+    you would usually subclass the *InfoHandler* class:
 
     >>> class MyHandler(chess.uci.InfoHandler):
     ...     def post_info(self):
@@ -191,8 +205,7 @@ class InfoHandler(object):
         sent by the engine.
         """
         if not lowerbound and not upperbound:
-            score = Score(cp, mate, lowerbound, upperbound)
-            self.info["score"][self.info.get("multipv", 1)] = score
+            self.info["score"][self.info.get("multipv", 1)] = Score(cp, mate)
 
     def currmove(self, move):
         """
@@ -1202,11 +1215,7 @@ class Engine(object):
         def command():
             with self.semaphore:
                 self.send_line(" ".join(builder))
-
-                with self.readyok_received:
-                    self.send_line("isready")
-                    self.readyok_received.wait()
-                    self.search_started.set()
+                self.search_started.set()
 
             self.bestmove_received.wait()
 
